@@ -153,6 +153,9 @@ func (args Attributes) Convert() beyla.Attributes {
 	attrs.Kubernetes.DisableInformers = args.Kubernetes.DisableInformers
 	attrs.Kubernetes.MetaRestrictLocalNode = args.Kubernetes.MetaRestrictLocalNode
 	attrs.Kubernetes.ClusterName = args.Kubernetes.ClusterName
+	if args.Kubernetes.MetaCacheAddress != "" {
+		attrs.Kubernetes.MetaCacheAddress = args.Kubernetes.MetaCacheAddress
+	}
 	// InstanceID
 	if args.InstanceID.HostnameDNSResolution {
 		attrs.InstanceID.HostnameDNSResolution = args.InstanceID.HostnameDNSResolution
@@ -444,6 +447,12 @@ func (args Metrics) Convert() prom.PrometheusConfig {
 		p.Instrumentations = args.Instrumentations
 	}
 	p.AllowServiceGraphSelfReferences = args.AllowServiceGraphSelfReferences
+	if args.ExtraResourceLabels != nil {
+		p.ExtraResourceLabels = args.ExtraResourceLabels
+	}
+	if args.ExtraSpanResourceLabels != nil {
+		p.ExtraSpanResourceLabels = args.ExtraSpanResourceLabels
+	}
 	return p
 }
 
