@@ -10,6 +10,7 @@ import (
 	"sort"
 	"strings"
 
+	"github.com/prometheus/common/model"
 	"github.com/prometheus/prometheus/model/exemplar"
 	"github.com/prometheus/prometheus/model/histogram"
 	"github.com/prometheus/prometheus/model/labels"
@@ -36,24 +37,34 @@ type metricFamily struct {
 // a couple data complexValue (buckets and count/sum), a group of a metric family always share a same set of tags. for
 // simple types like counter and gauge, each data point is a group of itself
 type metricGroup struct {
-	mtype        pmetric.MetricType
-	ts           int64
-	ls           labels.Labels
-	count        float64
-	hasCount     bool
-	sum          float64
-	hasSum       bool
-	created      float64
-	value        float64
-	hValue       *histogram.Histogram
-	fhValue      *histogram.FloatHistogram
-	complexValue []*dataPoint
-	exemplars    pmetric.ExemplarSlice
+	mtype    pmetric.MetricType
+	ts       int64
+	ls       labels.Labels
+	count    float64
+	hasCount bool
+	sum      float64
+	hasSum   bool
+	// This corresponds to the `_created` sample found from the metric parsing.
+	// - https://github.com/prometheus/OpenMetrics/blob/main/specification/OpenMetrics.md#timestamps
+	// - https://github.com/prometheus/OpenMetrics/blob/main/specification/OpenMetrics.md#counter-1
+	createdSeconds float64
+	value          float64
+	hValue         *histogram.Histogram
+	fhValue        *histogram.FloatHistogram
+	complexValue   []*dataPoint
+	exemplars      pmetric.ExemplarSlice
 }
 
-func newMetricFamily(metricName string, mc scrape.MetricMetadataStore, logger *zap.Logger) *metricFamily {
+func newMetricFamily(metricName string, mc scrape.MetricMetadataStore, logger *zap.Logger, isNativeHistogram, isNHCB bool) *metricFamily {
 	metadata, familyName := metadataForMetric(metricName, mc)
-	mtype, isMonotonic := convToMetricType(metadata.Type)
+	// Native histograms have intrinsic metric type, use it,
+	// regardless of what metadata says.
+	if isNativeHistogram {
+		metadata.Type = model.MetricTypeHistogram
+	}
+
+	mtype, isMonotonic := convToMetricType(metadata.Type, isNativeHistogram && !isNHCB)
+
 	if mtype == pmetric.MetricTypeEmpty {
 		logger.Debug(fmt.Sprintf("Unknown-typed metric : %s %+v", metricName, metadata))
 	}
@@ -143,8 +154,8 @@ func (mg *metricGroup) toDistributionPoint(dest pmetric.HistogramDataPointSlice)
 
 	// The timestamp MUST be in retrieved from milliseconds and converted to nanoseconds.
 	tsNanos := timestampFromMs(mg.ts)
-	if mg.created != 0 {
-		point.SetStartTimestamp(timestampFromFloat64(mg.created))
+	if mg.createdSeconds != 0 {
+		point.SetStartTimestamp(timestampFromFloat64(mg.createdSeconds))
 	} else if !removeStartTimeAdjustment.IsEnabled() {
 		// metrics_adjuster adjusts the startTimestamp to the initial scrape timestamp
 		point.SetStartTimestamp(tsNanos)
@@ -221,8 +232,8 @@ func (mg *metricGroup) toExponentialHistogramDataPoints(dest pmetric.Exponential
 	}
 
 	tsNanos := timestampFromMs(mg.ts)
-	if mg.created != 0 {
-		point.SetStartTimestamp(timestampFromFloat64(mg.created))
+	if mg.createdSeconds != 0 {
+		point.SetStartTimestamp(timestampFromFloat64(mg.createdSeconds))
 	} else if !removeStartTimeAdjustment.IsEnabled() {
 		// metrics_adjuster adjusts the startTimestamp to the initial scrape timestamp
 		point.SetStartTimestamp(tsNanos)
@@ -315,8 +326,8 @@ func (mg *metricGroup) toSummaryPoint(dest pmetric.SummaryDataPointSlice) {
 	// The timestamp MUST be in retrieved from milliseconds and converted to nanoseconds.
 	tsNanos := timestampFromMs(mg.ts)
 	point.SetTimestamp(tsNanos)
-	if mg.created != 0 {
-		point.SetStartTimestamp(timestampFromFloat64(mg.created))
+	if mg.createdSeconds != 0 {
+		point.SetStartTimestamp(timestampFromFloat64(mg.createdSeconds))
 	} else if !removeStartTimeAdjustment.IsEnabled() {
 		// metrics_adjuster adjusts the startTimestamp to the initial scrape timestamp
 		point.SetStartTimestamp(tsNanos)
@@ -329,8 +340,8 @@ func (mg *metricGroup) toNumberDataPoint(dest pmetric.NumberDataPointSlice) {
 	point := dest.AppendEmpty()
 	// gauge/undefined types have no start time.
 	if mg.mtype == pmetric.MetricTypeSum {
-		if mg.created != 0 {
-			point.SetStartTimestamp(timestampFromFloat64(mg.created))
+		if mg.createdSeconds != 0 {
+			point.SetStartTimestamp(timestampFromFloat64(mg.createdSeconds))
 		} else if !removeStartTimeAdjustment.IsEnabled() {
 			// metrics_adjuster adjusts the startTimestamp to the initial scrape timestamp
 			point.SetStartTimestamp(tsNanos)
@@ -398,7 +409,7 @@ func (mf *metricFamily) addSeries(seriesRef uint64, metricName string, ls labels
 			mg.count = v
 			mg.hasCount = true
 		case metricName == mf.metadata.MetricFamily+metricSuffixCreated:
-			mg.created = v
+			mg.createdSeconds = v
 		default:
 			boundary, err := getBoundary(mf.mtype, ls)
 			if err != nil {
@@ -408,16 +419,14 @@ func (mf *metricFamily) addSeries(seriesRef uint64, metricName string, ls labels
 		}
 	case pmetric.MetricTypeExponentialHistogram:
 		if metricName == mf.metadata.MetricFamily+metricSuffixCreated {
-			mg.created = v
+			mg.createdSeconds = v
 		}
 	case pmetric.MetricTypeSum:
 		if metricName == mf.metadata.MetricFamily+metricSuffixCreated {
-			mg.created = v
+			mg.createdSeconds = v
 		} else {
 			mg.value = v
 		}
-	case pmetric.MetricTypeEmpty, pmetric.MetricTypeGauge:
-		fallthrough
 	default:
 		mg.value = v
 	}
@@ -425,9 +434,12 @@ func (mf *metricFamily) addSeries(seriesRef uint64, metricName string, ls labels
 	return nil
 }
 
-func (mf *metricFamily) addCreationTimestamp(seriesRef uint64, ls labels.Labels, atMs, created int64) {
+// addCreationTimestamp updates the metric group cache with the created timestamp for the group.
+// The parser gets the created time in ms however and we must convert it to seconds here.
+// - https://github.com/prometheus/prometheus/blob/2bf6f4c9dcbb1ad2e8fef70c6a48d8fc44a7f57c/model/textparse/interface.go#L77-L80
+func (mf *metricFamily) addCreationTimestamp(seriesRef uint64, ls labels.Labels, atMs, ctMs int64) {
 	mg := mf.loadMetricGroupOrCreate(seriesRef, ls, atMs)
-	mg.created = float64(created)
+	mg.createdSeconds = float64(ctMs) / 1000.0
 }
 
 func (mf *metricFamily) addExponentialHistogramSeries(seriesRef uint64, metricName string, ls labels.Labels, t int64, h *histogram.Histogram, fh *histogram.FloatHistogram) error {
@@ -512,8 +524,6 @@ func (mf *metricFamily) appendMetric(metrics pmetric.MetricSlice, trimSuffixes b
 		}
 		pointCount = hdpL.Len()
 
-	case pmetric.MetricTypeEmpty, pmetric.MetricTypeGauge:
-		fallthrough
 	default: // Everything else should be set to a Gauge.
 		gauge := metric.SetEmptyGauge()
 		gdpL := gauge.DataPoints()
@@ -574,7 +584,7 @@ func convertExemplar(pe exemplar.Exemplar, e pmetric.Exemplar) {
 2. If len(src) = len(dst) -> copy src to dst as it is
 3. If len(src) < len(dst) -> prepend required 0s and then add src to dst. Example -> src = []byte{0xab, 0xcd}, dst = [8]byte, result dst = [8]byte{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xab, 0xcd}
 */
-func decodeAndCopyToLowerBytes(dst []byte, src []byte) error {
+func decodeAndCopyToLowerBytes(dst, src []byte) error {
 	var err error
 	decodedLen := hex.DecodedLen(len(src))
 	if decodedLen >= len(dst) {
