@@ -158,13 +158,10 @@ func (args Arguments) Convert() (otelcomponent.Config, error) {
 		c.BaseConfig.NonTransparentFramingTrailer = &s
 	}
 
-	tls := args.TCP.TLS.Convert()
-
 	if args.TCP != nil {
 		c.TCP = &stanzainputtcp.BaseConfig{
 			MaxLogSize:      helper.ByteSize(args.TCP.MaxLogSize),
 			ListenAddress:   args.TCP.ListenAddress,
-			TLS:             tls.Get(),
 			AddAttributes:   args.TCP.AddAttributes,
 			OneLogPerPacket: args.TCP.OneLogPerPacket,
 			Encoding:        args.TCP.Encoding,
@@ -180,6 +177,8 @@ func (args Arguments) Convert() (otelcomponent.Config, error) {
 		if trim != nil {
 			c.TCP.TrimConfig = *trim
 		}
+		tls := args.TCP.TLS.Convert()
+		c.TCP.TLS = tls.Get()
 	}
 
 	if args.UDP != nil {
