@@ -21,6 +21,7 @@ import (
 	"github.com/grafana/alloy/internal/component"
 	"github.com/grafana/alloy/internal/component/common/loki"
 	"github.com/grafana/alloy/internal/component/otelcol"
+	"github.com/grafana/alloy/internal/component/pyroscope"
 	"github.com/grafana/alloy/internal/dag"
 	"github.com/grafana/alloy/internal/featuregate"
 	"github.com/grafana/alloy/internal/nodeconf/foreach"
@@ -991,6 +992,7 @@ func setDataFlowEdges(n dag.Node, refs []astutil.Reference) {
 	otelConsumerType := reflect.TypeOf((*otelcol.Consumer)(nil)).Elem()
 	appendableType := reflect.TypeOf((*storage.Appendable)(nil)).Elem()
 	logsReceiverType := reflect.TypeOf((*loki.LogsReceiver)(nil)).Elem()
+	pyroscopeAppendableType := reflect.TypeOf((*pyroscope.Appendable)(nil)).Elem()
 	if cn, ok := n.(ComponentNode); ok {
 		for _, ref := range refs {
 			if tn, ok := ref.Target.(ComponentNode); ok {
@@ -1023,7 +1025,7 @@ func setDataFlowEdges(n dag.Node, refs []astutil.Reference) {
 				// For most export types, the data flow edge has the opposite direction of the reference.
 				if found {
 					switch field.Type {
-					case otelConsumerType, appendableType, logsReceiverType:
+					case otelConsumerType, appendableType, logsReceiverType, pyroscopeAppendableType:
 						cn.AddDataFlowEdgeTo(tn.NodeID())
 					default:
 						tn.AddDataFlowEdgeTo(cn.NodeID())
