@@ -3,15 +3,12 @@ package labelstore
 import "github.com/prometheus/prometheus/model/labels"
 
 type LabelStore interface {
-	// GetOrAddLink returns the global id for the values, if none found one will be created based on the lbls.
-	GetOrAddLink(componentID string, localRefID uint64, lbls labels.Labels) uint64
+	// AddLocalLink adds a mapping from local to global id for the given component.
+	AddLocalLink(componentID string, globalRefID uint64, localRefID uint64)
 
 	// GetOrAddGlobalRefID finds or adds a global id for the given label map.
 	GetOrAddGlobalRefID(l labels.Labels) uint64
 
-	// GetGlobalRefID returns the global id for a component and the local id. Returns 0 if nothing found.
-	GetGlobalRefID(componentID string, localRefID uint64) uint64
-
 	// GetLocalRefID gets the mapping from global to local id specific to a component. Returns 0 if nothing found.
 	GetLocalRefID(componentID string, globalRefID uint64) uint64
 
@@ -21,6 +18,9 @@ type LabelStore interface {
 
 	// CheckAndRemoveStaleMarkers identifies any series with a stale marker and removes those entries from the LabelStore.
 	CheckAndRemoveStaleMarkers()
+
+	// ReplaceLocalLink updates an existing local to global mapping for a component.
+	ReplaceLocalLink(componentID string, globalRefID uint64, cachedLocalRef uint64, newLocalRef uint64)
 }
 
 type StalenessTracker struct {
