@@ -10,21 +10,25 @@ import (
 
 // ObservabilityPipelineConfigDestinationItem - A destination for the pipeline.
 type ObservabilityPipelineConfigDestinationItem struct {
-	ObservabilityPipelineDatadogLogsDestination        *ObservabilityPipelineDatadogLogsDestination
-	ObservabilityPipelineAmazonS3Destination           *ObservabilityPipelineAmazonS3Destination
-	ObservabilityPipelineGoogleCloudStorageDestination *ObservabilityPipelineGoogleCloudStorageDestination
-	ObservabilityPipelineSplunkHecDestination          *ObservabilityPipelineSplunkHecDestination
-	ObservabilityPipelineSumoLogicDestination          *ObservabilityPipelineSumoLogicDestination
-	ObservabilityPipelineElasticsearchDestination      *ObservabilityPipelineElasticsearchDestination
-	ObservabilityPipelineRsyslogDestination            *ObservabilityPipelineRsyslogDestination
-	ObservabilityPipelineSyslogNgDestination           *ObservabilityPipelineSyslogNgDestination
-	AzureStorageDestination                            *AzureStorageDestination
-	MicrosoftSentinelDestination                       *MicrosoftSentinelDestination
-	ObservabilityPipelineGoogleChronicleDestination    *ObservabilityPipelineGoogleChronicleDestination
-	ObservabilityPipelineNewRelicDestination           *ObservabilityPipelineNewRelicDestination
-	ObservabilityPipelineSentinelOneDestination        *ObservabilityPipelineSentinelOneDestination
-	ObservabilityPipelineOpenSearchDestination         *ObservabilityPipelineOpenSearchDestination
-	ObservabilityPipelineAmazonOpenSearchDestination   *ObservabilityPipelineAmazonOpenSearchDestination
+	ObservabilityPipelineDatadogLogsDestination            *ObservabilityPipelineDatadogLogsDestination
+	ObservabilityPipelineAmazonS3Destination               *ObservabilityPipelineAmazonS3Destination
+	ObservabilityPipelineGoogleCloudStorageDestination     *ObservabilityPipelineGoogleCloudStorageDestination
+	ObservabilityPipelineSplunkHecDestination              *ObservabilityPipelineSplunkHecDestination
+	ObservabilityPipelineSumoLogicDestination              *ObservabilityPipelineSumoLogicDestination
+	ObservabilityPipelineElasticsearchDestination          *ObservabilityPipelineElasticsearchDestination
+	ObservabilityPipelineRsyslogDestination                *ObservabilityPipelineRsyslogDestination
+	ObservabilityPipelineSyslogNgDestination               *ObservabilityPipelineSyslogNgDestination
+	AzureStorageDestination                                *AzureStorageDestination
+	MicrosoftSentinelDestination                           *MicrosoftSentinelDestination
+	ObservabilityPipelineGoogleChronicleDestination        *ObservabilityPipelineGoogleChronicleDestination
+	ObservabilityPipelineNewRelicDestination               *ObservabilityPipelineNewRelicDestination
+	ObservabilityPipelineSentinelOneDestination            *ObservabilityPipelineSentinelOneDestination
+	ObservabilityPipelineOpenSearchDestination             *ObservabilityPipelineOpenSearchDestination
+	ObservabilityPipelineAmazonOpenSearchDestination       *ObservabilityPipelineAmazonOpenSearchDestination
+	ObservabilityPipelineSocketDestination                 *ObservabilityPipelineSocketDestination
+	ObservabilityPipelineAmazonSecurityLakeDestination     *ObservabilityPipelineAmazonSecurityLakeDestination
+	ObservabilityPipelineCrowdStrikeNextGenSiemDestination *ObservabilityPipelineCrowdStrikeNextGenSiemDestination
+	ObservabilityPipelineGooglePubSubDestination           *ObservabilityPipelineGooglePubSubDestination
 
 	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
 	UnparsedObject interface{}
@@ -105,6 +109,26 @@ func ObservabilityPipelineAmazonOpenSearchDestinationAsObservabilityPipelineConf
 	return ObservabilityPipelineConfigDestinationItem{ObservabilityPipelineAmazonOpenSearchDestination: v}
 }
 
+// ObservabilityPipelineSocketDestinationAsObservabilityPipelineConfigDestinationItem is a convenience function that returns ObservabilityPipelineSocketDestination wrapped in ObservabilityPipelineConfigDestinationItem.
+func ObservabilityPipelineSocketDestinationAsObservabilityPipelineConfigDestinationItem(v *ObservabilityPipelineSocketDestination) ObservabilityPipelineConfigDestinationItem {
+	return ObservabilityPipelineConfigDestinationItem{ObservabilityPipelineSocketDestination: v}
+}
+
+// ObservabilityPipelineAmazonSecurityLakeDestinationAsObservabilityPipelineConfigDestinationItem is a convenience function that returns ObservabilityPipelineAmazonSecurityLakeDestination wrapped in ObservabilityPipelineConfigDestinationItem.
+func ObservabilityPipelineAmazonSecurityLakeDestinationAsObservabilityPipelineConfigDestinationItem(v *ObservabilityPipelineAmazonSecurityLakeDestination) ObservabilityPipelineConfigDestinationItem {
+	return ObservabilityPipelineConfigDestinationItem{ObservabilityPipelineAmazonSecurityLakeDestination: v}
+}
+
+// ObservabilityPipelineCrowdStrikeNextGenSiemDestinationAsObservabilityPipelineConfigDestinationItem is a convenience function that returns ObservabilityPipelineCrowdStrikeNextGenSiemDestination wrapped in ObservabilityPipelineConfigDestinationItem.
+func ObservabilityPipelineCrowdStrikeNextGenSiemDestinationAsObservabilityPipelineConfigDestinationItem(v *ObservabilityPipelineCrowdStrikeNextGenSiemDestination) ObservabilityPipelineConfigDestinationItem {
+	return ObservabilityPipelineConfigDestinationItem{ObservabilityPipelineCrowdStrikeNextGenSiemDestination: v}
+}
+
+// ObservabilityPipelineGooglePubSubDestinationAsObservabilityPipelineConfigDestinationItem is a convenience function that returns ObservabilityPipelineGooglePubSubDestination wrapped in ObservabilityPipelineConfigDestinationItem.
+func ObservabilityPipelineGooglePubSubDestinationAsObservabilityPipelineConfigDestinationItem(v *ObservabilityPipelineGooglePubSubDestination) ObservabilityPipelineConfigDestinationItem {
+	return ObservabilityPipelineConfigDestinationItem{ObservabilityPipelineGooglePubSubDestination: v}
+}
+
 // UnmarshalJSON turns data into one of the pointers in the struct.
 func (obj *ObservabilityPipelineConfigDestinationItem) UnmarshalJSON(data []byte) error {
 	var err error
@@ -364,6 +388,74 @@ func (obj *ObservabilityPipelineConfigDestinationItem) UnmarshalJSON(data []byte
 		obj.ObservabilityPipelineAmazonOpenSearchDestination = nil
 	}
 
+	// try to unmarshal data into ObservabilityPipelineSocketDestination
+	err = datadog.Unmarshal(data, &obj.ObservabilityPipelineSocketDestination)
+	if err == nil {
+		if obj.ObservabilityPipelineSocketDestination != nil && obj.ObservabilityPipelineSocketDestination.UnparsedObject == nil {
+			jsonObservabilityPipelineSocketDestination, _ := datadog.Marshal(obj.ObservabilityPipelineSocketDestination)
+			if string(jsonObservabilityPipelineSocketDestination) == "{}" { // empty struct
+				obj.ObservabilityPipelineSocketDestination = nil
+			} else {
+				match++
+			}
+		} else {
+			obj.ObservabilityPipelineSocketDestination = nil
+		}
+	} else {
+		obj.ObservabilityPipelineSocketDestination = nil
+	}
+
+	// try to unmarshal data into ObservabilityPipelineAmazonSecurityLakeDestination
+	err = datadog.Unmarshal(data, &obj.ObservabilityPipelineAmazonSecurityLakeDestination)
+	if err == nil {
+		if obj.ObservabilityPipelineAmazonSecurityLakeDestination != nil && obj.ObservabilityPipelineAmazonSecurityLakeDestination.UnparsedObject == nil {
+			jsonObservabilityPipelineAmazonSecurityLakeDestination, _ := datadog.Marshal(obj.ObservabilityPipelineAmazonSecurityLakeDestination)
+			if string(jsonObservabilityPipelineAmazonSecurityLakeDestination) == "{}" { // empty struct
+				obj.ObservabilityPipelineAmazonSecurityLakeDestination = nil
+			} else {
+				match++
+			}
+		} else {
+			obj.ObservabilityPipelineAmazonSecurityLakeDestination = nil
+		}
+	} else {
+		obj.ObservabilityPipelineAmazonSecurityLakeDestination = nil
+	}
+
+	// try to unmarshal data into ObservabilityPipelineCrowdStrikeNextGenSiemDestination
+	err = datadog.Unmarshal(data, &obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination)
+	if err == nil {
+		if obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination != nil && obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination.UnparsedObject == nil {
+			jsonObservabilityPipelineCrowdStrikeNextGenSiemDestination, _ := datadog.Marshal(obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination)
+			if string(jsonObservabilityPipelineCrowdStrikeNextGenSiemDestination) == "{}" { // empty struct
+				obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination = nil
+			} else {
+				match++
+			}
+		} else {
+			obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination = nil
+		}
+	} else {
+		obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination = nil
+	}
+
+	// try to unmarshal data into ObservabilityPipelineGooglePubSubDestination
+	err = datadog.Unmarshal(data, &obj.ObservabilityPipelineGooglePubSubDestination)
+	if err == nil {
+		if obj.ObservabilityPipelineGooglePubSubDestination != nil && obj.ObservabilityPipelineGooglePubSubDestination.UnparsedObject == nil {
+			jsonObservabilityPipelineGooglePubSubDestination, _ := datadog.Marshal(obj.ObservabilityPipelineGooglePubSubDestination)
+			if string(jsonObservabilityPipelineGooglePubSubDestination) == "{}" { // empty struct
+				obj.ObservabilityPipelineGooglePubSubDestination = nil
+			} else {
+				match++
+			}
+		} else {
+			obj.ObservabilityPipelineGooglePubSubDestination = nil
+		}
+	} else {
+		obj.ObservabilityPipelineGooglePubSubDestination = nil
+	}
+
 	if match != 1 { // more than 1 match
 		// reset to nil
 		obj.ObservabilityPipelineDatadogLogsDestination = nil
@@ -381,6 +473,10 @@ func (obj *ObservabilityPipelineConfigDestinationItem) UnmarshalJSON(data []byte
 		obj.ObservabilityPipelineSentinelOneDestination = nil
 		obj.ObservabilityPipelineOpenSearchDestination = nil
 		obj.ObservabilityPipelineAmazonOpenSearchDestination = nil
+		obj.ObservabilityPipelineSocketDestination = nil
+		obj.ObservabilityPipelineAmazonSecurityLakeDestination = nil
+		obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination = nil
+		obj.ObservabilityPipelineGooglePubSubDestination = nil
 		return datadog.Unmarshal(data, &obj.UnparsedObject)
 	}
 	return nil // exactly one match
@@ -448,6 +544,22 @@ func (obj ObservabilityPipelineConfigDestinationItem) MarshalJSON() ([]byte, err
 		return datadog.Marshal(&obj.ObservabilityPipelineAmazonOpenSearchDestination)
 	}
 
+	if obj.ObservabilityPipelineSocketDestination != nil {
+		return datadog.Marshal(&obj.ObservabilityPipelineSocketDestination)
+	}
+
+	if obj.ObservabilityPipelineAmazonSecurityLakeDestination != nil {
+		return datadog.Marshal(&obj.ObservabilityPipelineAmazonSecurityLakeDestination)
+	}
+
+	if obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination != nil {
+		return datadog.Marshal(&obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination)
+	}
+
+	if obj.ObservabilityPipelineGooglePubSubDestination != nil {
+		return datadog.Marshal(&obj.ObservabilityPipelineGooglePubSubDestination)
+	}
+
 	if obj.UnparsedObject != nil {
 		return datadog.Marshal(obj.UnparsedObject)
 	}
@@ -516,6 +628,22 @@ func (obj *ObservabilityPipelineConfigDestinationItem) GetActualInstance() inter
 		return obj.ObservabilityPipelineAmazonOpenSearchDestination
 	}
 
+	if obj.ObservabilityPipelineSocketDestination != nil {
+		return obj.ObservabilityPipelineSocketDestination
+	}
+
+	if obj.ObservabilityPipelineAmazonSecurityLakeDestination != nil {
+		return obj.ObservabilityPipelineAmazonSecurityLakeDestination
+	}
+
+	if obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination != nil {
+		return obj.ObservabilityPipelineCrowdStrikeNextGenSiemDestination
+	}
+
+	if obj.ObservabilityPipelineGooglePubSubDestination != nil {
+		return obj.ObservabilityPipelineGooglePubSubDestination
+	}
+
 	// all schemas are nil
 	return nil
 }
