@@ -12,7 +12,6 @@ import (
 type SecurityMonitoringRuleOptions struct {
 	// Options for cloud_configuration rules.
 	// Fields `resourceType` and `regoRule` are mandatory when managing custom `cloud_configuration` rules.
-	//
 	ComplianceRuleOptions *CloudConfigurationComplianceRuleOptions `json:"complianceRuleOptions,omitempty"`
 	// If true, signals in non-production environments have a lower severity than what is defined by the rule case, which can reduce signal noise.
 	// The severity is decreased by one level: `CRITICAL` in production becomes `HIGH` in non-production, `HIGH` becomes `MEDIUM` and so on. `INFO` remains `INFO`.
@@ -35,6 +34,8 @@ type SecurityMonitoringRuleOptions struct {
 	MaxSignalDuration *SecurityMonitoringRuleMaxSignalDuration `json:"maxSignalDuration,omitempty"`
 	// Options on new value detection method.
 	NewValueOptions *SecurityMonitoringRuleNewValueOptions `json:"newValueOptions,omitempty"`
+	// Options on sequence detection method.
+	SequenceDetectionOptions *SecurityMonitoringRuleSequenceDetectionOptions `json:"sequenceDetectionOptions,omitempty"`
 	// Options on third party detection method.
 	ThirdPartyRuleOptions *SecurityMonitoringRuleThirdPartyOptions `json:"thirdPartyRuleOptions,omitempty"`
 	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
@@ -311,6 +312,34 @@ func (o *SecurityMonitoringRuleOptions) SetNewValueOptions(v SecurityMonitoringR
 	o.NewValueOptions = &v
 }
 
+// GetSequenceDetectionOptions returns the SequenceDetectionOptions field value if set, zero value otherwise.
+func (o *SecurityMonitoringRuleOptions) GetSequenceDetectionOptions() SecurityMonitoringRuleSequenceDetectionOptions {
+	if o == nil || o.SequenceDetectionOptions == nil {
+		var ret SecurityMonitoringRuleSequenceDetectionOptions
+		return ret
+	}
+	return *o.SequenceDetectionOptions
+}
+
+// GetSequenceDetectionOptionsOk returns a tuple with the SequenceDetectionOptions field value if set, nil otherwise
+// and a boolean to check if the value has been set.
+func (o *SecurityMonitoringRuleOptions) GetSequenceDetectionOptionsOk() (*SecurityMonitoringRuleSequenceDetectionOptions, bool) {
+	if o == nil || o.SequenceDetectionOptions == nil {
+		return nil, false
+	}
+	return o.SequenceDetectionOptions, true
+}
+
+// HasSequenceDetectionOptions returns a boolean if a field has been set.
+func (o *SecurityMonitoringRuleOptions) HasSequenceDetectionOptions() bool {
+	return o != nil && o.SequenceDetectionOptions != nil
+}
+
+// SetSequenceDetectionOptions gets a reference to the given SecurityMonitoringRuleSequenceDetectionOptions and assigns it to the SequenceDetectionOptions field.
+func (o *SecurityMonitoringRuleOptions) SetSequenceDetectionOptions(v SecurityMonitoringRuleSequenceDetectionOptions) {
+	o.SequenceDetectionOptions = &v
+}
+
 // GetThirdPartyRuleOptions returns the ThirdPartyRuleOptions field value if set, zero value otherwise.
 func (o *SecurityMonitoringRuleOptions) GetThirdPartyRuleOptions() SecurityMonitoringRuleThirdPartyOptions {
 	if o == nil || o.ThirdPartyRuleOptions == nil {
@@ -372,6 +401,9 @@ func (o SecurityMonitoringRuleOptions) MarshalJSON() ([]byte, error) {
 	if o.NewValueOptions != nil {
 		toSerialize["newValueOptions"] = o.NewValueOptions
 	}
+	if o.SequenceDetectionOptions != nil {
+		toSerialize["sequenceDetectionOptions"] = o.SequenceDetectionOptions
+	}
 	if o.ThirdPartyRuleOptions != nil {
 		toSerialize["thirdPartyRuleOptions"] = o.ThirdPartyRuleOptions
 	}
@@ -385,23 +417,24 @@ func (o SecurityMonitoringRuleOptions) MarshalJSON() ([]byte, error) {
 // UnmarshalJSON deserializes the given payload.
 func (o *SecurityMonitoringRuleOptions) UnmarshalJSON(bytes []byte) (err error) {
 	all := struct {
-		ComplianceRuleOptions         *CloudConfigurationComplianceRuleOptions       `json:"complianceRuleOptions,omitempty"`
-		DecreaseCriticalityBasedOnEnv *bool                                          `json:"decreaseCriticalityBasedOnEnv,omitempty"`
-		DetectionMethod               *SecurityMonitoringRuleDetectionMethod         `json:"detectionMethod,omitempty"`
-		EvaluationWindow              *SecurityMonitoringRuleEvaluationWindow        `json:"evaluationWindow,omitempty"`
-		HardcodedEvaluatorType        *SecurityMonitoringRuleHardcodedEvaluatorType  `json:"hardcodedEvaluatorType,omitempty"`
-		ImpossibleTravelOptions       *SecurityMonitoringRuleImpossibleTravelOptions `json:"impossibleTravelOptions,omitempty"`
-		KeepAlive                     *SecurityMonitoringRuleKeepAlive               `json:"keepAlive,omitempty"`
-		MaxSignalDuration             *SecurityMonitoringRuleMaxSignalDuration       `json:"maxSignalDuration,omitempty"`
-		NewValueOptions               *SecurityMonitoringRuleNewValueOptions         `json:"newValueOptions,omitempty"`
-		ThirdPartyRuleOptions         *SecurityMonitoringRuleThirdPartyOptions       `json:"thirdPartyRuleOptions,omitempty"`
+		ComplianceRuleOptions         *CloudConfigurationComplianceRuleOptions        `json:"complianceRuleOptions,omitempty"`
+		DecreaseCriticalityBasedOnEnv *bool                                           `json:"decreaseCriticalityBasedOnEnv,omitempty"`
+		DetectionMethod               *SecurityMonitoringRuleDetectionMethod          `json:"detectionMethod,omitempty"`
+		EvaluationWindow              *SecurityMonitoringRuleEvaluationWindow         `json:"evaluationWindow,omitempty"`
+		HardcodedEvaluatorType        *SecurityMonitoringRuleHardcodedEvaluatorType   `json:"hardcodedEvaluatorType,omitempty"`
+		ImpossibleTravelOptions       *SecurityMonitoringRuleImpossibleTravelOptions  `json:"impossibleTravelOptions,omitempty"`
+		KeepAlive                     *SecurityMonitoringRuleKeepAlive                `json:"keepAlive,omitempty"`
+		MaxSignalDuration             *SecurityMonitoringRuleMaxSignalDuration        `json:"maxSignalDuration,omitempty"`
+		NewValueOptions               *SecurityMonitoringRuleNewValueOptions          `json:"newValueOptions,omitempty"`
+		SequenceDetectionOptions      *SecurityMonitoringRuleSequenceDetectionOptions `json:"sequenceDetectionOptions,omitempty"`
+		ThirdPartyRuleOptions         *SecurityMonitoringRuleThirdPartyOptions        `json:"thirdPartyRuleOptions,omitempty"`
 	}{}
 	if err = datadog.Unmarshal(bytes, &all); err != nil {
 		return datadog.Unmarshal(bytes, &o.UnparsedObject)
 	}
 	additionalProperties := make(map[string]interface{})
 	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
-		datadog.DeleteKeys(additionalProperties, &[]string{"complianceRuleOptions", "decreaseCriticalityBasedOnEnv", "detectionMethod", "evaluationWindow", "hardcodedEvaluatorType", "impossibleTravelOptions", "keepAlive", "maxSignalDuration", "newValueOptions", "thirdPartyRuleOptions"})
+		datadog.DeleteKeys(additionalProperties, &[]string{"complianceRuleOptions", "decreaseCriticalityBasedOnEnv", "detectionMethod", "evaluationWindow", "hardcodedEvaluatorType", "impossibleTravelOptions", "keepAlive", "maxSignalDuration", "newValueOptions", "sequenceDetectionOptions", "thirdPartyRuleOptions"})
 	} else {
 		return err
 	}
@@ -445,6 +478,10 @@ func (o *SecurityMonitoringRuleOptions) UnmarshalJSON(bytes []byte) (err error)
 		hasInvalidField = true
 	}
 	o.NewValueOptions = all.NewValueOptions
+	if all.SequenceDetectionOptions != nil && all.SequenceDetectionOptions.UnparsedObject != nil && o.UnparsedObject == nil {
+		hasInvalidField = true
+	}
+	o.SequenceDetectionOptions = all.SequenceDetectionOptions
 	if all.ThirdPartyRuleOptions != nil && all.ThirdPartyRuleOptions.UnparsedObject != nil && o.UnparsedObject == nil {
 		hasInvalidField = true
 	}
