@@ -339,7 +339,7 @@ func isEOF(ch rune) bool {
 
 // isIdentifier checks if a rune is an identifier
 func isIdentifier(ch rune) bool {
-	return ch == '.' || ch == '?' || ch == '$' || ch == '#' || ch == '/' || ch == '@' || ch == '!' || isLetter(ch) || isDigit(ch)
+	return ch == '"' || ch == '.' || ch == '?' || ch == '$' || ch == '#' || ch == '/' || ch == '@' || ch == '!' || isLetter(ch) || isDigit(ch)
 }
 
 // isValueToken checks if a token is a value token
