@@ -6,6 +6,7 @@ package request
 import (
 	"encoding/json"
 	"fmt"
+	"net/url"
 	"strconv"
 	"strings"
 	"time"
@@ -45,6 +46,16 @@ const (
 	EventTypeGPUMemcpy
 )
 
+const (
+	envOTLPProtocol        = "OTEL_EXPORTER_OTLP_PROTOCOL"
+	envOTLPTracesProtocol  = "OTEL_EXPORTER_OTLP_TRACES_PROTOCOL"
+	envOTLPMetricsProtocol = "OTEL_EXPORTER_OTLP_METRICS_PROTOCOL"
+	envOTLPEndpoint        = "OTEL_EXPORTER_OTLP_ENDPOINT"
+	envOTLPTracesEndpoint  = "OTEL_EXPORTER_OTLP_TRACES_ENDPOINT"
+	envOTLPMetricsEndpoint = "OTEL_EXPORTER_OTLP_METRICS_ENDPOINT"
+	otlpGrpcProtocol       = "grpc"
+)
+
 const (
 	metricsDetectPattern     = "/v1/metrics"
 	grpcMetricsDetectPattern = "/opentelemetry.proto.collector.metrics.v1.MetricsService/Export"
@@ -140,6 +151,11 @@ type SQLError struct {
 	Message  string `json:"message"`
 }
 
+type MessagingInfo struct {
+	Offset    int64 `json:"offset"`
+	Partition int   `json:"partition"`
+}
+
 // Span contains the information being submitted by the following nodes in the graph.
 // It enables comfortable handling of data from Go.
 // REMINDER: any attribute here must be also added to the functions SpanOTELGetters,
@@ -175,6 +191,7 @@ type Span struct {
 	DBNamespace    string         `json:"-"`
 	SQLCommand     string         `json:"-"`
 	SQLError       *SQLError      `json:"-"`
+	MessagingInfo  *MessagingInfo `json:"-"`
 
 	// OverrideTraceName is set under some conditions, like spanmetrics reaching the maximum
 	// cardinality for trace names.
@@ -264,13 +281,21 @@ func spanAttributes(s *Span) SpanAttributes {
 			"statement":  s.Statement,
 			"query":      s.Path,
 		}
-	case EventTypeKafkaServer:
-		return SpanAttributes{
+	case EventTypeKafkaServer, EventTypeKafkaClient:
+		attrs := SpanAttributes{
 			"serverAddr": SpanHost(s),
 			"serverPort": strconv.Itoa(s.HostPort),
 			"operation":  s.Method,
-			"clientId":   s.OtherNamespace,
+			"clientId":   s.Statement,
+			"topic":      s.Path,
 		}
+		if s.MessagingInfo != nil {
+			attrs["partition"] = strconv.FormatUint(uint64(s.MessagingInfo.Partition), 10)
+			if s.Method == MessagingProcess {
+				attrs["offset"] = strconv.FormatUint(uint64(s.MessagingInfo.Offset), 10)
+			}
+		}
+		return attrs
 	case EventTypeGPUKernelLaunch:
 		return SpanAttributes{
 			"function":  s.Method,
@@ -398,6 +423,10 @@ func (s *Span) IsClientSpan() bool {
 	return false
 }
 
+func (s *Span) IsHTTPSpan() bool {
+	return s.Type == EventTypeHTTP || s.Type == EventTypeHTTPClient
+}
+
 const (
 	StatusCodeUnset = "STATUS_CODE_UNSET"
 	StatusCodeError = "STATUS_CODE_ERROR"
@@ -554,11 +583,11 @@ func (s *Span) TraceName() string {
 		if s.Path == "" {
 			return s.Method
 		}
-		return fmt.Sprintf("%s %s", s.Path, s.Method)
+		return s.Method + " " + s.Path
 	case EventTypeMongoClient:
 		if s.Path != "" && s.Method != "" {
 			// TODO for database operations like listCollections, we need to use s.DbNamespace instead of s.Path
-			return fmt.Sprintf("%s %s", s.Method, s.Path)
+			return s.Method + " " + s.Path
 		}
 		if s.Path != "" {
 			return s.Path
@@ -599,22 +628,96 @@ func (s *Span) isTracesExportURL() bool {
 	}
 }
 
-func (s *Span) IsExportMetricsSpan() bool {
-	// check if it's a successful client call
-	if !s.isHTTPOrGRPCClient() || (SpanStatusCode(s) != StatusCodeUnset) {
-		return false
+func (s *Span) sendsOnDefaultGrpcOtelPort(defaultOtlpGRPCPort int) bool {
+	otlpPort, ok := s.portFromEndpointEnvVar(envOTLPEndpoint)
+	if ok {
+		return otlpPort == s.PeerPort
 	}
-
-	return s.isMetricsExportURL()
+	return s.PeerPort == defaultOtlpGRPCPort
 }
 
-func (s *Span) IsExportTracesSpan() bool {
+func (s *Span) sendsTracesOnGrpcOtelPort(defaultOtlpGRPCPort int) bool {
+	otlpTracesProtocol, ok := s.Service.EnvVars[envOTLPTracesProtocol]
+	if ok && otlpTracesProtocol != otlpGrpcProtocol {
+		return false
+	}
+	otlpProtocol, ok := s.Service.EnvVars[envOTLPProtocol]
+	if ok && otlpProtocol != otlpGrpcProtocol {
+		return false
+	}
+	otlpTracesPort, ok := s.portFromEndpointEnvVar(envOTLPTracesEndpoint)
+	if ok {
+		return otlpTracesPort == s.PeerPort
+	}
+	return s.sendsOnDefaultGrpcOtelPort(defaultOtlpGRPCPort)
+}
+
+func (s *Span) sendsMetricsOnOtelPort(defaultOtlpGRPCPort int) bool {
+	switch s.Type {
+	case EventTypeGRPCClient:
+		return s.sendsMetricsOnGrpcOtelPort(defaultOtlpGRPCPort)
+	default:
+		return false
+	}
+}
+
+func (s *Span) sendsTracesOnOtelPort(defaultOtlpGRPCPort int) bool {
+	switch s.Type {
+	case EventTypeGRPCClient:
+		return s.sendsTracesOnGrpcOtelPort(defaultOtlpGRPCPort)
+	default:
+		return false
+	}
+}
+
+func (s *Span) sendsMetricsOnGrpcOtelPort(defaultOtlpGRPCPort int) bool {
+	otlpMetricsProtocol, ok := s.Service.EnvVars[envOTLPMetricsProtocol]
+	if ok && otlpMetricsProtocol != otlpGrpcProtocol {
+		return false
+	}
+	otlpProtocol, ok := s.Service.EnvVars[envOTLPProtocol]
+	if ok && otlpProtocol != otlpGrpcProtocol {
+		return false
+	}
+	otlpMetricsPort, ok := s.portFromEndpointEnvVar(envOTLPMetricsEndpoint)
+	if ok {
+		return otlpMetricsPort == s.PeerPort
+	}
+	return s.sendsOnDefaultGrpcOtelPort(defaultOtlpGRPCPort)
+}
+
+func (s *Span) portFromEndpointEnvVar(envVarName string) (int, bool) {
+	endpoint, ok := s.Service.EnvVars[envVarName]
+	if !ok {
+		return 0, false
+	}
+	parsedURL, err := url.Parse(endpoint)
+	if err != nil || parsedURL == nil {
+		return 0, false
+	}
+	port, err := strconv.Atoi(parsedURL.Port())
+	if err != nil {
+		return 0, false
+	}
+	return port, true
+}
+
+func (s *Span) IsExportMetricsSpan(defaultOtlpGRPCPort int) bool {
 	// check if it's a successful client call
 	if !s.isHTTPOrGRPCClient() || (SpanStatusCode(s) != StatusCodeUnset) {
 		return false
 	}
 
-	return s.isTracesExportURL()
+	return s.isMetricsExportURL() || s.sendsMetricsOnOtelPort(defaultOtlpGRPCPort)
+}
+
+func (s *Span) IsExportTracesSpan(defaultOtlpGRPCPort int) bool {
+	// check if it's a successful client call
+	if !s.isHTTPOrGRPCClient() || (SpanStatusCode(s) != StatusCodeUnset) {
+		return false
+	}
+
+	return s.isTracesExportURL() || s.sendsTracesOnOtelPort(defaultOtlpGRPCPort)
 }
 
 func (s *Span) IsSelfReferenceSpan() bool {
