@@ -59,9 +59,21 @@ func SetValue(value pcommon.Value, val any) error {
 			err = SetValue(pval, a)
 		}
 	case pcommon.Slice:
-		v.CopyTo(value.SetEmptySlice())
+		var dest pcommon.Slice
+		if value.Type() == pcommon.ValueTypeSlice {
+			dest = value.Slice()
+		} else {
+			dest = value.SetEmptySlice()
+		}
+		v.CopyTo(dest)
 	case pcommon.Map:
-		v.CopyTo(value.SetEmptyMap())
+		var dest pcommon.Map
+		if value.Type() == pcommon.ValueTypeMap {
+			dest = value.Map()
+		} else {
+			dest = value.SetEmptyMap()
+		}
+		v.CopyTo(dest)
 	case map[string]any:
 		err = value.FromRaw(v)
 	}
@@ -71,7 +83,7 @@ func SetValue(value pcommon.Value, val any) error {
 func getIndexableValue[K any](ctx context.Context, tCtx K, value pcommon.Value, keys []ottl.Key[K]) (any, error) {
 	val := value
 	var ok bool
-	for index := 0; index < len(keys); index++ {
+	for index := range keys {
 		switch val.Type() {
 		case pcommon.ValueTypeMap:
 			s, err := GetMapKeyName(ctx, tCtx, keys[index])
@@ -106,7 +118,7 @@ func getIndexableValue[K any](ctx context.Context, tCtx K, value pcommon.Value,
 }
 
 func SetIndexableValue[K any](ctx context.Context, tCtx K, currentValue pcommon.Value, val any, keys []ottl.Key[K]) error {
-	for index := 0; index < len(keys); index++ {
+	for index := range keys {
 		switch currentValue.Type() {
 		case pcommon.ValueTypeMap:
 			s, err := GetMapKeyName(ctx, tCtx, keys[index])
