@@ -14,7 +14,7 @@ import (
 
 type KeepKeysArguments[K any] struct {
 	Target ottl.PMapGetSetter[K]
-	Keys   []string
+	Keys   []ottl.StringGetter[K]
 }
 
 func NewKeepKeysFactory[K any]() ottl.Factory[K] {
@@ -31,10 +31,16 @@ func createKeepKeysFunction[K any](_ ottl.FunctionContext, oArgs ottl.Arguments)
 	return keepKeys(args.Target, args.Keys), nil
 }
 
-func keepKeys[K any](target ottl.PMapGetSetter[K], keys []string) ottl.ExprFunc[K] {
-	keySet := make(map[string]struct{}, len(keys))
+func keepKeys[K any](target ottl.PMapGetSetter[K], keys []ottl.StringGetter[K]) ottl.ExprFunc[K] {
+	// Check if all keys are literals and pre-build the key set if so
+	literalKeySet := make(map[string]struct{}, len(keys))
 	for _, key := range keys {
-		keySet[key] = struct{}{}
+		k, isLiteral := ottl.GetLiteralValue(key)
+		if !isLiteral {
+			literalKeySet = nil
+			break
+		}
+		literalKeySet[k] = struct{}{}
 	}
 
 	return func(ctx context.Context, tCtx K) (any, error) {
@@ -42,6 +48,23 @@ func keepKeys[K any](target ottl.PMapGetSetter[K], keys []string) ottl.ExprFunc[
 		if err != nil {
 			return nil, err
 		}
+
+		var keySet map[string]struct{}
+		if literalKeySet != nil {
+			// Use pre-built key set for literal keys
+			keySet = literalKeySet
+		} else {
+			// Build key set at runtime for dynamic keys
+			keySet = make(map[string]struct{}, len(keys))
+			for _, key := range keys {
+				k, err := key.Get(ctx, tCtx)
+				if err != nil {
+					return nil, err
+				}
+				keySet[k] = struct{}{}
+			}
+		}
+
 		val.RemoveIf(func(key string, _ pcommon.Value) bool {
 			_, ok := keySet[key]
 			return !ok
