@@ -19,12 +19,14 @@ import (
 	"github.com/open-telemetry/opentelemetry-collector-contrib/internal/filter/filterlog"
 	"github.com/open-telemetry/opentelemetry-collector-contrib/internal/filter/filterottl"
 	"github.com/open-telemetry/opentelemetry-collector-contrib/pkg/ottl/contexts/ottllog"
+	"github.com/open-telemetry/opentelemetry-collector-contrib/pkg/ottl/contexts/ottlresource"
 )
 
 type filterLogProcessor struct {
-	skipExpr  expr.BoolExpr[ottllog.TransformContext]
-	telemetry *filterTelemetry
-	logger    *zap.Logger
+	skipResourceExpr  expr.BoolExpr[ottlresource.TransformContext]
+	skipLogRecordExpr expr.BoolExpr[ottllog.TransformContext]
+	telemetry         *filterTelemetry
+	logger            *zap.Logger
 }
 
 func newFilterLogsProcessor(set processor.Settings, cfg *Config) (*filterLogProcessor, error) {
@@ -38,12 +40,20 @@ func newFilterLogsProcessor(set processor.Settings, cfg *Config) (*filterLogProc
 	}
 	flp.telemetry = fpt
 
-	if cfg.Logs.LogConditions != nil {
-		skipExpr, errBoolExpr := filterottl.NewBoolExprForLog(cfg.Logs.LogConditions, cfg.logFunctions, cfg.ErrorMode, set.TelemetrySettings)
-		if errBoolExpr != nil {
-			return nil, errBoolExpr
+	if cfg.Logs.ResourceConditions != nil || cfg.Logs.LogConditions != nil {
+		if cfg.Logs.ResourceConditions != nil {
+			flp.skipResourceExpr, err = filterottl.NewBoolExprForResource(cfg.Logs.ResourceConditions, cfg.resourceFunctions, cfg.ErrorMode, set.TelemetrySettings)
+			if err != nil {
+				return nil, err
+			}
+		}
+
+		if cfg.Logs.LogConditions != nil {
+			flp.skipLogRecordExpr, err = filterottl.NewBoolExprForLog(cfg.Logs.LogConditions, cfg.logFunctions, cfg.ErrorMode, set.TelemetrySettings)
+			if err != nil {
+				return nil, err
+			}
 		}
-		flp.skipExpr = skipExpr
 		return flp, nil
 	}
 
@@ -60,13 +70,13 @@ func newFilterLogsProcessor(set processor.Settings, cfg *Config) (*filterLogProc
 	if err != nil {
 		return nil, fmt.Errorf("failed to build skip matcher: %w", err)
 	}
-	flp.skipExpr = skipExpr
+	flp.skipLogRecordExpr = skipExpr
 
 	return flp, nil
 }
 
 func (flp *filterLogProcessor) processLogs(ctx context.Context, ld plog.Logs) (plog.Logs, error) {
-	if flp.skipExpr == nil {
+	if flp.skipResourceExpr == nil && flp.skipLogRecordExpr == nil {
 		return ld, nil
 	}
 
@@ -75,11 +85,24 @@ func (flp *filterLogProcessor) processLogs(ctx context.Context, ld plog.Logs) (p
 	var errors error
 	ld.ResourceLogs().RemoveIf(func(rl plog.ResourceLogs) bool {
 		resource := rl.Resource()
+		if flp.skipResourceExpr != nil {
+			skip, err := flp.skipResourceExpr.Eval(ctx, ottlresource.NewTransformContext(resource, rl))
+			if err != nil {
+				errors = multierr.Append(errors, err)
+				return false
+			}
+			if skip {
+				return true
+			}
+		}
+		if flp.skipLogRecordExpr == nil {
+			return rl.ScopeLogs().Len() == 0
+		}
 		rl.ScopeLogs().RemoveIf(func(sl plog.ScopeLogs) bool {
 			scope := sl.Scope()
 			lrs := sl.LogRecords()
 			lrs.RemoveIf(func(lr plog.LogRecord) bool {
-				skip, err := flp.skipExpr.Eval(ctx, ottllog.NewTransformContext(lr, scope, resource, sl, rl))
+				skip, err := flp.skipLogRecordExpr.Eval(ctx, ottllog.NewTransformContext(lr, scope, resource, sl, rl))
 				if err != nil {
 					errors = multierr.Append(errors, err)
 					return false
